.. _api_reference:

API Reference
=============

The following gives detailed information about all sparrowpy functions sorted
according to their modules.

For examples on how to use sparrowpy refer to the notebooks in the
`examples`_ and the documentation on classes and modules below.


Classes
-------

.. toctree::
   :maxdepth: 1

   classes/sparrowpy.RadiosityKang
   classes/sparrowpy.RadiosityFast

Modules
-------

.. toctree::
   :maxdepth: 1

   modules/sparrowpy.geometry
   modules/sparrowpy.sound_object
   modules/sparrowpy.brdf


.. _examples: https://github.com/sparrow-acoustics/sparrowpy/tree/main/examples
